
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

            #pragma once

            #include <glib-object.h>
            #if !defined(_ADWAITA_INSIDE) && !defined(ADWAITA_COMPILATION)
#error "Only <adwaita.h> can be included directly."
#endif

#include "adw-version.h"

            G_BEGIN_DECLS

/* enumerations from "adw-accent-color.h" */

ADW_AVAILABLE_IN_ALL
GType adw_accent_color_get_type (void);
#define ADW_TYPE_ACCENT_COLOR (adw_accent_color_get_type())

/* enumerations from "adw-alert-dialog.h" */

ADW_AVAILABLE_IN_ALL
GType adw_response_appearance_get_type (void);
#define ADW_TYPE_RESPONSE_APPEARANCE (adw_response_appearance_get_type())

/* enumerations from "adw-animation.h" */

ADW_AVAILABLE_IN_ALL
GType adw_animation_state_get_type (void);
#define ADW_TYPE_ANIMATION_STATE (adw_animation_state_get_type())

/* enumerations from "adw-banner.h" */

ADW_AVAILABLE_IN_ALL
GType adw_banner_button_style_get_type (void);
#define ADW_TYPE_BANNER_BUTTON_STYLE (adw_banner_button_style_get_type())

/* enumerations from "adw-breakpoint.h" */

ADW_AVAILABLE_IN_ALL
GType adw_breakpoint_condition_length_type_get_type (void);
#define ADW_TYPE_BREAKPOINT_CONDITION_LENGTH_TYPE (adw_breakpoint_condition_length_type_get_type())

ADW_AVAILABLE_IN_ALL
GType adw_breakpoint_condition_ratio_type_get_type (void);
#define ADW_TYPE_BREAKPOINT_CONDITION_RATIO_TYPE (adw_breakpoint_condition_ratio_type_get_type())

/* enumerations from "adw-dialog.h" */

ADW_AVAILABLE_IN_ALL
GType adw_dialog_presentation_mode_get_type (void);
#define ADW_TYPE_DIALOG_PRESENTATION_MODE (adw_dialog_presentation_mode_get_type())

/* enumerations from "adw-easing.h" */

ADW_AVAILABLE_IN_ALL
GType adw_easing_get_type (void);
#define ADW_TYPE_EASING (adw_easing_get_type())

/* enumerations from "adw-flap.h" */

ADW_AVAILABLE_IN_ALL
GType adw_flap_fold_policy_get_type (void);
#define ADW_TYPE_FLAP_FOLD_POLICY (adw_flap_fold_policy_get_type())

ADW_AVAILABLE_IN_ALL
GType adw_flap_transition_type_get_type (void);
#define ADW_TYPE_FLAP_TRANSITION_TYPE (adw_flap_transition_type_get_type())

/* enumerations from "adw-fold-threshold-policy.h" */

ADW_AVAILABLE_IN_ALL
GType adw_fold_threshold_policy_get_type (void);
#define ADW_TYPE_FOLD_THRESHOLD_POLICY (adw_fold_threshold_policy_get_type())

/* enumerations from "adw-header-bar.h" */

ADW_AVAILABLE_IN_ALL
GType adw_centering_policy_get_type (void);
#define ADW_TYPE_CENTERING_POLICY (adw_centering_policy_get_type())

/* enumerations from "adw-inline-view-switcher.h" */

ADW_AVAILABLE_IN_ALL
GType adw_inline_view_switcher_display_mode_get_type (void);
#define ADW_TYPE_INLINE_VIEW_SWITCHER_DISPLAY_MODE (adw_inline_view_switcher_display_mode_get_type())

/* enumerations from "adw-leaflet.h" */

ADW_AVAILABLE_IN_ALL
GType adw_leaflet_transition_type_get_type (void);
#define ADW_TYPE_LEAFLET_TRANSITION_TYPE (adw_leaflet_transition_type_get_type())

/* enumerations from "adw-length-unit.h" */

ADW_AVAILABLE_IN_ALL
GType adw_length_unit_get_type (void);
#define ADW_TYPE_LENGTH_UNIT (adw_length_unit_get_type())

/* enumerations from "adw-navigation-direction.h" */

ADW_AVAILABLE_IN_ALL
GType adw_navigation_direction_get_type (void);
#define ADW_TYPE_NAVIGATION_DIRECTION (adw_navigation_direction_get_type())

/* enumerations from "adw-squeezer.h" */

ADW_AVAILABLE_IN_ALL
GType adw_squeezer_transition_type_get_type (void);
#define ADW_TYPE_SQUEEZER_TRANSITION_TYPE (adw_squeezer_transition_type_get_type())

/* enumerations from "adw-style-manager.h" */

ADW_AVAILABLE_IN_ALL
GType adw_color_scheme_get_type (void);
#define ADW_TYPE_COLOR_SCHEME (adw_color_scheme_get_type())

/* enumerations from "adw-tab-view.h" */

ADW_AVAILABLE_IN_ALL
GType adw_tab_view_shortcuts_get_type (void);
#define ADW_TYPE_TAB_VIEW_SHORTCUTS (adw_tab_view_shortcuts_get_type())

/* enumerations from "adw-toast.h" */

ADW_AVAILABLE_IN_ALL
GType adw_toast_priority_get_type (void);
#define ADW_TYPE_TOAST_PRIORITY (adw_toast_priority_get_type())

/* enumerations from "adw-toolbar-view.h" */

ADW_AVAILABLE_IN_ALL
GType adw_toolbar_style_get_type (void);
#define ADW_TYPE_TOOLBAR_STYLE (adw_toolbar_style_get_type())

/* enumerations from "adw-view-switcher.h" */

ADW_AVAILABLE_IN_ALL
GType adw_view_switcher_policy_get_type (void);
#define ADW_TYPE_VIEW_SWITCHER_POLICY (adw_view_switcher_policy_get_type())

/* enumerations from "adw-wrap-layout.h" */

ADW_AVAILABLE_IN_ALL
GType adw_justify_mode_get_type (void);
#define ADW_TYPE_JUSTIFY_MODE (adw_justify_mode_get_type())

ADW_AVAILABLE_IN_ALL
GType adw_pack_direction_get_type (void);
#define ADW_TYPE_PACK_DIRECTION (adw_pack_direction_get_type())

ADW_AVAILABLE_IN_ALL
GType adw_wrap_policy_get_type (void);
#define ADW_TYPE_WRAP_POLICY (adw_wrap_policy_get_type())

G_END_DECLS

/* Generated data ends here */

